pub struct Client { /* private fields */ }Expand description
The main struct to interact with the Bitwarden SDK.
Implementations
Sourceimpl Client
impl Client
Sourcepub fn new(settings: Option<ClientSettings>) -> Self
pub fn new(settings: Option<ClientSettings>) -> Self
Create a new Bitwarden client with default settings and a no-op token handler.
Sourcepub fn new_with_token_handler(
settings: Option<ClientSettings>,
token_handler: Arc<dyn TokenHandler>,
) -> Self
pub fn new_with_token_handler( settings: Option<ClientSettings>, token_handler: Arc<dyn TokenHandler>, ) -> Self
Create a new Bitwarden client with the specified token handler for managing authentication tokens.
fn new_internal( settings_input: Option<ClientSettings>, token_handler: Arc<dyn TokenHandler>, ) -> Self
Sourceimpl Client
impl Client
pub async fn init_test_account(account: TestAccount) -> Self